@@ -61,6 +61,31 @@ class TestOITWebServicesLibrary(unittest.TestCase):
         self.assertTrue(headerValue2)
         self.assertTrue(headerValue1 != headerValue2)
 
+    def test_get_nonce(self):
+        apiKey = 'YF4i2Qdx2WuSj-G8583M'
+        nonce = oit.get_nonce(apiKey, verify=False)
+        self.assertTrue('nonceKey' in nonce)
+        self.assertTrue('nonceValue' in nonce)
+
+    def test_send_ws_request(self):
+        _, _, _, res = oit.send_ws_request('http://www.byu.edu/',
+                                           'GET',
+                                           None,)
+        self.assertTrue(res.status_code, 200)
+
+    def test_failed_authorize_request(self):
+        apiKey = 'YF4i2Qdx2WuSj-G8583M'
+        sharedSecret = '98F8wh62cAt8OuufF2rY3B1MSelA8MArV_Zg4CJ9'
+        headerValue = oit.get_http_authorization_header(apiKey,
+                                                        sharedSecret,
+                                                        oit.KEY_TYPE_API,
+                                                        oit.ENCODING_URL,
+                                                        "http://www.byu.edu/",
+                                                        "")
+        res = oit.authorize_request('http://www.byu.edu/', headerValue, apiKey,
+                                    sharedSecret, verify=False)
+        self.assertTrue(res is None)
+
 
 if __name__ == "__main__":
     unittest.main()
